#include "histogram.hpp"
#include <vector>

bool find_minmax(std::vector<double> &numbers, double& min, double& max)
{
    if (numbers.empty()) return false;
    min = numbers[0]; max = numbers[0];
    for (double x : numbers)
    {
        if (max < x)
            max = x;
        if (min > x)
            min = x;
    }
    return true;
}

std::vector<size_t> make_histogram(std::vector<double> numbers, size_t bin_count)
{
    double min, max;
    find_minmax(numbers, min, max);
    double bin_size = (max - min) / bin_count;
    std::vector<size_t> bins(bin_count);
    for (size_t i = 0; i < numbers.size(); i++)
    {
        bool found = false;
        for (size_t j = 0; (j < bin_count - 1) && !found; j++)
        {
            auto lo = min + j * bin_size;
            auto hi = min + (j + 1) * bin_size;
            if ((lo <= numbers[i]) && (numbers[i] < hi))
            {
                bins[j]++;
                found = true;
            }
        }
        if (!found)
        {
            bins[bin_count - 1]++;
        }
    }
    return bins;
}
